﻿;/////////////////////////////////////////////////////////////////////////////////
;Demo of the OOP class for implementing hash tables.

;By Stephen Rodriguez.

;Demonstrates some of the methods exposed by the 'HashTableObject' class.
;/////////////////////////////////////////////////////////////////////////////////

XIncludeFile "HashTableClass.pbi"
DisableExplicit

;The following structure represents the data stored for each item added to a hash table.
;You can call this structure anything you wish and add any fields you wish, but you must
;observe the following rules :
; i) The first field MUST be put aside for the key$ value,
; ii) all remaining string fields must immediately follow the key$ field.
  Structure MyHashTableItemData
    key$
    SomeText$
    SomeValue.l
  EndStructure


;Create a hash table object with 100 items.
;The value of #True tells the library that this hash table will be accessed by multiple threads
;and results in the library automatically using mutexes to protect shared access etc.
;(This example doesn't actually require this protection, it's just included for completeness!)
  MyHashTableObject.HashTableObject
  MyHashTableObject = NewHashTable(100, SizeOf(MyHashTableItemData), 2, #True) 
    ;The 2 is used as a notification of how many string fields there are in our data structure.
    ;The #True is optional.


If MyHashTableObject ;Always check that the object was created successfully.

;Add some data to the hash table.
  HT_ITEM.MyHashTableItemData
    HT_ITEM\key$ = "index10"
    HT_ITEM\SomeText$ = "Hello"
    HT_ITEM\SomeValue = 100
  MyHashTableObject\AddItem(HT_ITEM)
    HT_ITEM\key$ = "index7"
    HT_ITEM\SomeText$ = "bananas!"
    HT_ITEM\SomeValue = 1000
  MyHashTableObject\AddItem(HT_ITEM)

;Let us retrieve the first item added.
  HT_ITEM\key$ = "index10"
  If MyHashTableObject\GetItem(HT_ITEM)
    Debug "Retrieved the first value. SomeText$ = " + HT_ITEM\SomeText$
  EndIf

;Let us retrieve the second item added.
  HT_ITEM\key$ = "index7"
  If MyHashTableObject\GetItem(HT_ITEM)
    Debug "Retrieved the second value. SomeText$ = " + HT_ITEM\SomeText$
  EndIf

;Is there an entry with the key "poo" ?
  If MyHashTableObject\IsKeyPresent("poo")
    Debug "Key = 'poo' found!"
  Else
    Debug "Key = 'poo' not found!"
  EndIf

;Let us remove the first item.
  MyHashTableObject\RemoveItem("index10")
;And check that the key no longer exists.
  If MyHashTableObject\IsKeyPresent("index10")
    Debug "Key = 'index10' has NOT been removed!"
  Else
    Debug "Key = 'index10' has been removed!"
  EndIf


;Destroy the hash table when finished.
  MyHashTableObject\Destroy()

Else
  MessageRequester("Error :", "There was a memory allocation problem creating the hash table object.")
EndIf


; IDE Options = PureBasic 4.40 Beta 3 (Windows - x86)
; CursorPosition = 59
; FirstLine = 47