﻿;/////////////////////////////////////////////////////////////////////////////////
;Demo of the OOP class for implementing hash tables.

;By Stephen Rodriguez.

;Demonstrates the EnumKeys() method which is used to enumerate all the keys etc.
;within a hash table object.
;/////////////////////////////////////////////////////////////////////////////////

XIncludeFile "HashTableClass.pbi"
DisableExplicit


;The following structure represents the data stored for each item added to a hash table.
;You can call this structure anything you wish and add any fields you wish, but you must
;observe the following rules :
; i) The first field MUST be put aside for the key$ value,
; ii) all remaining string fields must immediately follow the key$ field.
  Structure MyHashTableItemData
    key$
    SomeText$
    SomeValue.l
  EndStructure


;The following function is used by the EnumKeys() method.
Procedure EnumKeysCallback(key$, *ptr.MyHashTableItemData, lParam)
  Debug "Enum : key = " + key$ + ".    SomeText$ = " + *ptr\SomeText$
   ProcedureReturn #True ;To continue the enumeration.
EndProcedure



;Create a hash table object with 100 items.
;The value of #True tells the library that this hash table will be accessed by multiple threads
;and results in the library automatically using mutexes to protect shared access etc.
;(This example doesn't actually require this protection, it's just included for completeness!)
  MyHashTableObject.HashTableObject
  MyHashTableObject = NewHashTable(100, SizeOf(MyHashTableItemData), 2, #True) 
    ;The 2 is used as a notification of how many string fields there are in our data structure.
    ;The #True is optional.


If MyHashTableObject ;Always check that the object was created successfully.

;Add some data to the hash table.
  HT_ITEM.MyHashTableItemData
    HT_ITEM\key$ = "index10"
    HT_ITEM\SomeText$ = "Hello"
    HT_ITEM\SomeValue = 100
  MyHashTableObject\AddItem(HT_ITEM)
    HT_ITEM\key$ = "index7"
    HT_ITEM\SomeText$ = "bananas!"
    HT_ITEM\SomeValue = 1000
  MyHashTableObject\AddItem(HT_ITEM)

;Let us enumerate through all the keys.
  MyHashTableObject\EnumKeys(@EnumKeysCallback())

;Destroy the hash table when finished.
  MyHashTableObject\Destroy()

Else
  MessageRequester("Error :", "There was a memory allocation problem creating the hash table object.")
EndIf


; IDE Options = PureBasic 4.40 (Windows - x86)
; CursorPosition = 47
; FirstLine = 31
; Folding = -
; EnableUnicode
; EnableThread